[Scummvm-git-logs] scummvm master -> f125ffb89c59f9f8ad56090f151cc09f52c9f76f

dreammaster dreammaster at scummvm.org
Fri Apr 27 04:17:56 CEST 2018


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
f125ffb89c XEEN: Script patch for Dark Tower statue setting invalid world flag


Commit: f125ffb89c59f9f8ad56090f151cc09f52c9f76f
    https://github.com/scummvm/scummvm/commit/f125ffb89c59f9f8ad56090f151cc09f52c9f76f
Author: Paul Gilbert (dreammaster at scummvm.org)
Date: 2018-04-26T22:17:54-04:00

Commit Message:
XEEN: Script patch for Dark Tower statue setting invalid world flag

Changed paths:
    engines/xeen/patcher.cpp


diff --git a/engines/xeen/patcher.cpp b/engines/xeen/patcher.cpp
index 280724c..5c2442c 100644
--- a/engines/xeen/patcher.cpp
+++ b/engines/xeen/patcher.cpp
@@ -37,11 +37,13 @@ struct ScriptEntry {
 
 const byte DS_MAP54_LINE8[] = { 8, 10, 10, DIR_EAST, 8, OP_MoveWallObj, 20, 100, 100 };
 const byte SW_MAP53_LINE8[] = { 5, 14, 6, DIR_EAST, 8, OP_Exit };
+const byte DS_MAP116[] = { 9, 10, 6, 4, 2, OP_TakeOrGive, 0, 0, 103, 127 };
 
-#define SCRIPT_PATCHES_COUNT 2
+#define SCRIPT_PATCHES_COUNT 3
 static const ScriptEntry SCRIPT_PATCHES[] = {
 	{ GType_DarkSide, 54, DS_MAP54_LINE8 },	// Fix curtain on level 2 of Ellinger's Tower
-	{ GType_Swords, 53, SW_MAP53_LINE8 }	// Fix chest in Hart having gems, but saying "Nothing Here"
+	{ GType_Swords, 53, SW_MAP53_LINE8 },	// Fix chest in Hart having gems, but saying "Nothing Here"
+	{ GType_DarkSide, 116, DS_MAP116 }		// Fix statue in Dark Tower setting invalid world flag
 };
 
 /*------------------------------------------------------------------------*/





More information about the Scummvm-git-logs mailing list